package ClassLoader.Test;

import java.io.InputStream;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.Properties;

public class ClassLoaderTest {

    public ClassLoaderTest() {
    }

    public void checkClassLoader() {
        try {
            // returns the Class object associated with this class
            Class<?> cls = Class.forName("ClassLoader.Test.ClassLoaderTest");

            // returns the ClassLoader object associated with this Class.
            ClassLoader cLoader = cls.getClassLoader();

            if (cLoader == null) {
                System.out.println("The default system class was used.");
            }
            else {
                ClassLoader cl = ClassLoader.getSystemClassLoader();

                URL[] urls = ((URLClassLoader) cl).getURLs();

                for (URL url : urls) {
                    System.out.println(url.getFile());
                }

                // returns the class loader
                Class<? extends ClassLoader> loaderClass = cLoader.getClass();

                System.out.println("Class associated with ClassLoader = " + loaderClass.getName());
                URL url = cLoader.getResource("ClassLoader/Test/JForexPlatformSettings.xml");
                if (url == null) {
                    System.out.println("No valid URL for XML file");
                }
                else {
                    System.out.println("URL is valid with: " + url.toString());
                }

                //This works, but the file is included in the jar!
                InputStream is = cLoader.getResourceAsStream("ClassLoader/Test/JForexPlatformSettings.xml");

                if (is == null) {
                    System.out.println("InputStream 1could not been initialized with XML file!");
                }
                else {
                    System.out.println("InputStream 1 constructed with XML file!");
                }

                //All these do not work!!
                InputStream is2 = cLoader.getResourceAsStream("/JForexPlatformSettings.xml");
                InputStream is3 = cLoader.getResourceAsStream("./JForexPlatformSettings.xml");
                InputStream is4 = cLoader.getResourceAsStream("/../JForexPlatformSettings.xml");

                if (is2 == null) {
                    System.out.println("InputStream 2 could not been initialized with XML file!");
                }
                else {
                    System.out.println("InputStream 2 constructed with XML file!");
                }
                if (is3 == null) {
                    System.out.println("InputStream 3 could not been initialized with XML file!");
                }
                else {
                    System.out.println("InputStream 3 constructed with XML file!");
                }
                if (is4 == null) {
                    System.out.println("InputStream 4 could not been initialized with XML file!");
                }
                else {
                    System.out.println("InputStream 4 constructed with XML file!");
                }

                final Properties properties = new Properties();
                try {
                    properties.loadFromXML(is);
                    System.out.println("slippage= " + properties.getProperty("order.default.slippage"));
                } catch (Exception e) {
                    System.out.println("Some exception occured while loading XML file!");
                }

            }
        } catch (ClassNotFoundException e) {
            System.out.println(e.toString());
        }
    }
}
